@@ -2,4 +2,9 @@ from nimba.http import router, render
 
 @router('/')
 def home(request):
-    return "Nimba Framework installed succesfuly!"
+    return render('awesome_app/home.html')
+
+
+@router('/articles')
+def home(request):
+    return 'testing <h1>OK</h1>'
